@Timeout(Duration(seconds: 300))
import 'package:tailor/tailor.dart' show TailorDB, join, File, Directory;
import 'package:instant/instant.dart';
import 'package:test/test.dart';
import 'package:hive/hive.dart';

void main() async {
  Hive.init(join(Directory.current.path, 'test'));
  var hive = await Hive.openBox('testdb');
  var tailor = TailorDB(file: File(join(Directory.current.path, 'test', 'db.json')));

  setUp(() {
    hive.clear();
    tailor.clear();
  });

  print('Hive vs. Tailor on Writes:');
    var sw = InstantStopwatch()..play();
    for (var i = 0; i<200000; i++) {
      tailor.add(key: 'Key: $i', value: 'Value: $i');
    }
    tailor.writeCache();
    var tailortime = sw.stopwatchInMilliseconds;
    sw.reset();
    sw.play();
    for (var i = 0; i<200000; i++) {
      hive.put('Key: $i', 'Value: $i');
    }
    sw.pause();
    var hivetime = sw.stopwatchInMilliseconds;
    print('Tailor Writes: $tailortime ms');
    print('Hive Writes: $hivetime ms');
  print('');

  print('Hive vs. Tailor on Reads:');
    var sw2 = InstantStopwatch()..play();
    for (var i = 0; i<200000; i++) {
      tailor.get(key: 'Key: $i');
    }
    var tailortime2 = sw2.stopwatchInMilliseconds;
    print('Tailor Reads: $tailortime2 ms');
    sw.reset();
    sw.play();
    for (var i = 0; i<200000; i++) {
      hive.get('Key: $i');
    }
    sw.pause();
    var hivetime2 = sw2.stopwatchInMilliseconds;
    print('Hive Reads: $hivetime2 ms');
  print('');

  print('Hive vs. Tailor on Deletes:');
    var sw3 = InstantStopwatch()..play();
    for (var i = 0; i<200000; i++) {
      tailor.remove(key: 'Key: $i');
    }
    tailor.writeCache();
    var tailortime3 = sw3.stopwatchInMilliseconds;
    print('Tailor Deletes: $tailortime3 ms');
    sw.reset();
    sw.play();
    for (var i = 0; i<200000; i++) {
      hive.delete('Key: $i');
    }
    sw.pause();
    var hivetime3 = sw3.stopwatchInMilliseconds;
  print('Hive Deletes: $hivetime3 ms');

}
